"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.resolveIntegrationHubHost = exports.resolveIntegrationHubBaseUrl = exports.resolveErrorResponse = exports.didRequestFail = exports.createWebhookSecretKey = exports.processAsIntegrationHubErrorResponse = exports.handleCatchError = void 0;
const uuid_1 = require("uuid");
const error_messages_1 = require("./error-messages");
function handleCatchError(err) {
    return err instanceof Error ? err : new Error("Unknown error occurred");
}
exports.handleCatchError = handleCatchError;
function processAsIntegrationHubErrorResponse(result) {
    var _a, _b;
    if (result.error) {
        return {
            success: false,
            error: new Error(`${(_a = result.error) === null || _a === void 0 ? void 0 : _a.name} - ${(_b = result.error) === null || _b === void 0 ? void 0 : _b.message}`),
        };
    }
    return {
        success: false,
        error: new Error("No error information was provided."),
    };
}
exports.processAsIntegrationHubErrorResponse = processAsIntegrationHubErrorResponse;
function createWebhookSecretKey() {
    return (0, uuid_1.v4)();
}
exports.createWebhookSecretKey = createWebhookSecretKey;
function didRequestFail(response) {
    return !response.success;
}
exports.didRequestFail = didRequestFail;
function resolveErrorResponse(code, error) {
    return {
        success: false,
        name: "algolia",
        code,
        reason: error_messages_1.errorMessages[code],
        error,
    };
}
exports.resolveErrorResponse = resolveErrorResponse;
function resolveIntegrationHubBaseUrl(region) {
    return `https://${resolveIntegrationHubHost(region)}.elasticpathintegrations.com/api/`;
}
exports.resolveIntegrationHubBaseUrl = resolveIntegrationHubBaseUrl;
function resolveIntegrationHubHost(region) {
    switch (region) {
        case "eu-west":
            return "eu-west-1";
        case "us-east":
            return "us-east-2";
        default:
            return "us-east-2";
    }
}
exports.resolveIntegrationHubHost = resolveIntegrationHubHost;
