"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.embeddedAuthentication = exports.integrationAuthToken = void 0;
const tslib_1 = require("tslib");
const node_fetch_1 = tslib_1.__importDefault(require("node-fetch"));
const resolve_epcc_url_1 = require("../../utility/resolve-epcc-url");
const helpers_1 = require("../helpers");
const utility_1 = require("../../utility");
function integrationAuthToken(host, accessToken) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        const url = `${(0, resolve_epcc_url_1.resolveEpccBaseUrl)(host)}/v2/platform-integrations/authentication-token`;
        const resp = yield (0, node_fetch_1.default)(url, {
            headers: {
                Authorization: `Bearer ${accessToken}`,
            },
        }).then((resp) => resp.json());
        if (!isSuccessResponse(resp)) {
            return {
                success: false,
                error: new Error("Failed to get integrations authentication token."),
            };
        }
        const jwtToken = resp.data.jwt_token;
        const embeddedAuthenticationResult = yield embeddedAuthentication(host, jwtToken);
        if (!embeddedAuthenticationResult.success) {
            return {
                success: false,
                error: new Error("Failed to embedded authenticate integrations authentication token."),
            };
        }
        return { success: true, data: { jwtToken } };
    });
}
exports.integrationAuthToken = integrationAuthToken;
function embeddedAuthentication(host, ihToken) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        const url = `https://${(0, helpers_1.resolveIntegrationHubHost)((0, utility_1.resolveRegion)(host))}.elasticpathintegrations.com/embedded/authenticate`;
        const resp = yield (0, node_fetch_1.default)(url, {
            method: "POST",
            headers: {
                Authorization: `Bearer ${ihToken}`,
            },
        });
        if (!resp.ok) {
            return {
                success: false,
                error: new Error("Failed to embedded authenticate integrations authentication token."),
            };
        }
        return { success: true, data: { ihToken } };
    });
}
exports.embeddedAuthentication = embeddedAuthentication;
function isSuccessResponse(resp) {
    return typeof resp === "object" && resp !== null && "data" in resp;
}
