import { __awaiter } from "tslib";
import fetch from "node-fetch";
import { resolveEpccBaseUrl } from "../../utility/resolve-epcc-url";
import { resolveIntegrationHubHost } from "../helpers";
import { resolveRegion } from "../../utility";
export function integrationAuthToken(host, accessToken) {
    return __awaiter(this, void 0, void 0, function* () {
        const url = `${resolveEpccBaseUrl(host)}/v2/platform-integrations/authentication-token`;
        const resp = yield fetch(url, {
            headers: {
                Authorization: `Bearer ${accessToken}`,
            },
        }).then((resp) => resp.json());
        if (!isSuccessResponse(resp)) {
            return {
                success: false,
                error: new Error("Failed to get integrations authentication token."),
            };
        }
        const jwtToken = resp.data.jwt_token;
        const embeddedAuthenticationResult = yield embeddedAuthentication(host, jwtToken);
        if (!embeddedAuthenticationResult.success) {
            return {
                success: false,
                error: new Error("Failed to embedded authenticate integrations authentication token."),
            };
        }
        return { success: true, data: { jwtToken } };
    });
}
export function embeddedAuthentication(host, ihToken) {
    return __awaiter(this, void 0, void 0, function* () {
        const url = `https://${resolveIntegrationHubHost(resolveRegion(host))}.elasticpathintegrations.com/embedded/authenticate`;
        const resp = yield fetch(url, {
            method: "POST",
            headers: {
                Authorization: `Bearer ${ihToken}`,
            },
        });
        if (!resp.ok) {
            return {
                success: false,
                error: new Error("Failed to embedded authenticate integrations authentication token."),
            };
        }
        return { success: true, data: { ihToken } };
    });
}
function isSuccessResponse(resp) {
    return typeof resp === "object" && resp !== null && "data" in resp;
}
